__version__ = '0.0.19'
__title__ = 'sla-runner'
__description__ = 'A continuous test runner for gathering SLA data'
__url__ = 'https://github.com/billtrust/sla-monitor-runner'
__author__ = 'Jaime Wissner'
__author_email__ = 'jwissner@billtrust.com'
__license__ = 'MIT'
__keywords__ = ['sla-testing', 'aws-sla-reporting', 'sla-monitor', 'sla', 'continuous runner']
